package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.IndustryCategory;

/**
 * 行业类别Service接口
 * 
 * @author ruoyi
 * @date 2024-04-23
 */
public interface IIndustryCategoryService 
{
    /**
     * 查询行业类别
     * 
     * @param categoryId 行业类别主键
     * @return 行业类别
     */
    public IndustryCategory selectIndustryCategoryByCategoryId(Long categoryId);

    /**
     * 查询行业类别列表
     * 
     * @param industryCategory 行业类别
     * @return 行业类别集合
     */
    public List<IndustryCategory> selectIndustryCategoryList(IndustryCategory industryCategory);

    /**
     * 新增行业类别
     * 
     * @param industryCategory 行业类别
     * @return 结果
     */
    public int insertIndustryCategory(IndustryCategory industryCategory);

    /**
     * 修改行业类别
     * 
     * @param industryCategory 行业类别
     * @return 结果
     */
    public int updateIndustryCategory(IndustryCategory industryCategory);

    /**
     * 批量删除行业类别
     * 
     * @param categoryIds 需要删除的行业类别主键集合
     * @return 结果
     */
    public int deleteIndustryCategoryByCategoryIds(Long[] categoryIds);

    /**
     * 删除行业类别信息
     * 
     * @param categoryId 行业类别主键
     * @return 结果
     */
    public int deleteIndustryCategoryByCategoryId(Long categoryId);

    List<TreeSelect> selectCategoryTreeList(IndustryCategory industryCategory);

    public List<TreeSelect> buildCategoryTreeSelect(List<IndustryCategory> industryCategorys);
}
